alloc_binary

Function alloc_binary 

pub unsafe fn alloc_binary(size: usize, bin: *mut Binary) -> c_int
Allocates a new, mutable binary.

Allocates size bytes and initializes bin to refer to them, returning a non-zero value on success or 0 on failure. The binary is owned by the caller until it is handed to a term with make_binary or discarded with release_binary.

enif_alloc_binary — NIF 0.1 — OTP R13B03