#[repr(i32)]pub enum CharEncoding {
Latin1 = 1,
Utf8 = 2,
}Expand description
Encoding for reading and writing atom and string bytes.
Selects how the byte buffer in functions like make_atom, get_string,
and make_string is interpreted. Latin1 is one byte per character;
Utf8 (NIF 2.17) is variable-width.
ErlNifCharEncoding — NIF 1.0 — OTP R13B04
Variants
Latin1 = 1
Latin-1 (ISO-8859-1).
ERL_NIF_LATIN1 — NIF 1.0 — OTP R13B04
Utf8 = 2
UTF-8.
ERL_NIF_UTF8 — NIF 2.17 — OTP 26